@@ -44,13 +44,16 @@
 #include <qcoreapplication.h>
 #include <qqmlengine.h>
 #include <qdir.h>
+#include <QTouchDevice>
+#include <QGuiApplication>
+#include <QStyleHints>
 
 QT_BEGIN_NAMESPACE
 
 static QString defaultStyleName()
 {
     //Only enable QStyle support when we are using QApplication
-#if !defined(Q_OS_IOS) && !defined(Q_OS_ANDROID) && !defined (Q_OS_BLACKBERRY)
+#if defined(QT_WIDGETS_LIB) && !defined(Q_OS_IOS) && !defined(Q_OS_ANDROID) && !defined(Q_OS_BLACKBERRY) && !defined(Q_OS_QNX) && !defined(Q_OS_WINRT)
     if (QCoreApplication::instance()->inherits("QApplication"))
         return QLatin1String("Desktop");
 #endif
@@ -72,9 +75,13 @@ static bool fromResource(const QString &path)
 
 bool QQuickControlSettings::hasTouchScreen() const
 {
-#if defined(Q_OS_IOS) || defined(Q_OS_ANDROID) || defined (Q_OS_BLACKBERRY)
+// QTBUG-36007
+#if defined(Q_OS_ANDROID)
     return true;
 #else
+    foreach (const QTouchDevice *dev, QTouchDevice::devices())
+        if (dev->type() == QTouchDevice::TouchScreen)
+            return true;
     return false;
 #endif
 }
@@ -83,7 +90,9 @@ static QString styleImportPath(QQmlEngine *engine, const QString &styleName)
 {
     QString path = qgetenv("QT_QUICK_CONTROLS_STYLE");
     QFileInfo info(path);
-    if (info.isRelative()) {
+    if (fromResource(path)) {
+        path = info.path();
+    } else if (info.isRelative()) {
         bool found = false;
         foreach (const QString &import, engine->importPathList()) {
             QDir dir(import + QLatin1String("/QtQuick/Controls/Styles"));
@@ -170,5 +179,10 @@ qreal QQuickControlSettings::dpiScaleFactor() const
     return 1.0;
 }
 
+qreal QQuickControlSettings::dragThreshold() const
+{
+    return qApp->styleHints()->startDragDistance();
+}
+
 
 QT_END_NAMESPACE
