@@ -41,6 +41,7 @@
 
 #include "qquicklinearlayout_p.h"
 #include "qquickgridlayoutengine_p.h"
+#include "qquicklayoutstyleinfo_p.h"
 #include <QtCore/qnumeric.h>
 #include "qdebug.h"
 #include <limits>
@@ -68,6 +69,39 @@
         \li \l{Layout::alignment}{Layout.alignment}
     \endlist
 
+    \image rowlayout.png
+
+    \code
+    RowLayout {
+        id: layout
+        anchors.fill: parent
+        spacing: 6
+        Rectangle {
+            color: 'teal'
+            Layout.fillWidth: true
+            Layout.minimumWidth: 50
+            Layout.preferredWidth: 100
+            Layout.maximumWidth: 300
+            Layout.minimumHeight: 150
+            Text {
+                anchors.centerIn: parent
+                text: parent.width + 'x' + parent.height
+            }
+        }
+        Rectangle {
+            color: 'plum'
+            Layout.fillWidth: true
+            Layout.minimumWidth: 100
+            Layout.preferredWidth: 200
+            Layout.preferredHeight: 100
+            Text {
+                anchors.centerIn: parent
+                text: parent.width + 'x' + parent.height
+            }
+        }
+    }
+    \endcode
+
     Read more about attached properties \l{QML Object Attributes}{here}.
     \sa ColumnLayout
     \sa GridLayout
@@ -97,6 +131,36 @@
         \li \l{Layout::alignment}{Layout.alignment}
     \endlist
 
+    \image columnlayout.png
+
+    \code
+    ColumnLayout{
+        spacing: 2
+
+        Rectangle {
+            Layout.alignment: Qt.AlignCenter
+            color: "red"
+            Layout.preferredWidth: 40
+            Layout.preferredHeight: 40
+        }
+
+        Rectangle {
+            Layout.alignment: Qt.AlignRight
+            color: "green"
+            Layout.preferredWidth: 40
+            Layout.preferredHeight: 70
+        }
+
+        Rectangle {
+            Layout.alignment: Qt.AlignBottom
+            Layout.fillHeight: true
+            color: "blue"
+            Layout.preferredWidth: 70
+            Layout.preferredHeight: 40
+        }
+    }
+    \endcode
+
     Read more about attached properties \l{QML Object Attributes}{here}.
 
     \sa RowLayout
@@ -113,6 +177,8 @@
     \ingroup layouts
     \brief Provides a way of dynamically arranging items in a grid.
 
+
+
     If the GridLayout is resized, all items in the layout will be rearranged. It is similar
     to the widget-based QGridLayout. All visible children of the GridLayout element will belong to
     the layout. If you want a layout with just one row or one column, you can use the
@@ -126,16 +192,19 @@
     columns the layout can have, before the auto-positioning wraps back to the beginning of the
     next row. The \l columns property is only used when \l flow is  \c GridLayout.LeftToRight.
 
+    \image gridlayout.png
+
     \code
-        GridLayout {
-            id: grid
-            columns: 3
-            Text { text: "Three" }
-            Text { text: "words" }
-            Text { text: "in" }
-            Text { text: "a" }
-            Text { text: "row" }
-        }
+    GridLayout {
+        id: grid
+        columns: 3
+
+        Text { text: "Three"; font.bold: true; }
+        Text { text: "words"; color: "red" }
+        Text { text: "in"; font.underline: true }
+        Text { text: "a"; font.pixelSize: 20 }
+        Text { text: "row"; font.strikeout: true }
+    }
     \endcode
 
     The \l rows property works in a similar way, but items are auto-positioned vertically. The \l
@@ -175,14 +244,10 @@
 
 QT_BEGIN_NAMESPACE
 
-static qreal quickLayoutDefaultSpacing()
+QQuickGridLayoutBase::QQuickGridLayoutBase()
+    : QQuickLayout(*new QQuickGridLayoutBasePrivate)
 {
-    qreal spacing = 5.0;
-#ifndef Q_OS_MAC
-    // On mac the DPI is always 72 so we should not scale it
-    spacing = qRound(spacing * (qreal(qt_defaultDpiX()) / 96.0));
-#endif
-    return spacing;
+
 }
 
 QQuickGridLayoutBase::QQuickGridLayoutBase(QQuickGridLayoutBasePrivate &dd,
@@ -192,6 +257,7 @@ QQuickGridLayoutBase::QQuickGridLayoutBase(QQuickGridLayoutBasePrivate &dd,
 {
     Q_D(QQuickGridLayoutBase);
     d->orientation = orientation;
+    d->styleInfo = new QQuickLayoutStyleInfo;
 }
 
 Qt::Orientation QQuickGridLayoutBase::orientation() const
@@ -213,7 +279,7 @@ void QQuickGridLayoutBase::setOrientation(Qt::Orientation orientation)
 QSizeF QQuickGridLayoutBase::sizeHint(Qt::SizeHint whichSizeHint) const
 {
     Q_D(const QQuickGridLayoutBase);
-    return d->engine.sizeHint(whichSizeHint, QSizeF());
+    return d->engine.sizeHint(whichSizeHint, QSizeF(), d->styleInfo);
 }
 
 /*!
@@ -221,14 +287,14 @@ QSizeF QQuickGridLayoutBase::sizeHint(Qt::SizeHint whichSizeHint) const
     \since QtQuick.Layouts 1.1
 
     This property holds the layout direction of the grid layout - it controls whether items are
-    laid out from left ro right or right to left. If \c Qt.RightToLeft is specified,
+    laid out from left to right or right to left. If \c Qt.RightToLeft is specified,
     left-aligned items will be right-aligned and right-aligned items will be left-aligned.
 
     Possible values:
 
     \list
     \li Qt.LeftToRight (default) - Items are laid out from left to right.
-    \li Qt.RightToLeft - Items are laid out from right to left
+    \li Qt.RightToLeft - Items are laid out from right to left.
     \endlist
 
     \sa RowLayout::layoutDirection, ColumnLayout::layoutDirection
@@ -261,7 +327,8 @@ void QQuickGridLayoutBase::setAlignment(QQuickItem *item, Qt::Alignment alignmen
 
 QQuickGridLayoutBase::~QQuickGridLayoutBase()
 {
-    d_func()->m_isReady = false;
+    Q_D(QQuickGridLayoutBase);
+    d->m_isReady = false;
 
     /* Avoid messy deconstruction, should give:
         * Faster deconstruction
@@ -274,6 +341,7 @@ QQuickGridLayoutBase::~QQuickGridLayoutBase()
         QObject::disconnect(item, SIGNAL(implicitWidthChanged()), this, SLOT(invalidateSenderItem()));
         QObject::disconnect(item, SIGNAL(implicitHeightChanged()), this, SLOT(invalidateSenderItem()));
     }
+    delete d->styleInfo;
 }
 
 void QQuickGridLayoutBase::componentComplete()
@@ -499,9 +567,10 @@ void QQuickGridLayoutBase::rearrange(const QSizeF &size)
         qSwap(left, right);
     */
 
-    d->engine.setGeometries(QRectF(QPointF(0,0), size));
-
+    // Set m_dirty to false in case size hint changes during arrangement.
+    // This could happen if there is a binding like implicitWidth: height
     QQuickLayout::rearrange(size);
+    d->engine.setGeometries(QRectF(QPointF(0,0), size), d->styleInfo);
 }
 
 bool QQuickGridLayoutBase::shouldIgnoreItem(QQuickItem *child, QQuickLayoutAttached *&info, QSizeF *sizeHints)
@@ -534,32 +603,26 @@ bool QQuickGridLayoutBase::shouldIgnoreItem(QQuickItem *child, QQuickLayoutAttac
 QQuickGridLayout::QQuickGridLayout(QQuickItem *parent /* = 0*/)
     : QQuickGridLayoutBase(*new QQuickGridLayoutPrivate, Qt::Horizontal, parent)
 {
-    Q_D(QQuickGridLayout);
-    const qreal defaultSpacing = quickLayoutDefaultSpacing();
-    d->columnSpacing = defaultSpacing;
-    d->rowSpacing = defaultSpacing;
-    d->engine.setSpacing(defaultSpacing, Qt::Horizontal | Qt::Vertical);
 }
 
 /*!
     \qmlproperty real GridLayout::columnSpacing
 
     This property holds the spacing between each column.
-    The default value is \c 4.
+    The default value is \c 5.
 */
 qreal QQuickGridLayout::columnSpacing() const
 {
     Q_D(const QQuickGridLayout);
-    return d->columnSpacing;
+    return d->engine.spacing(Qt::Horizontal, d->styleInfo);
 }
 
 void QQuickGridLayout::setColumnSpacing(qreal spacing)
 {
     Q_D(QQuickGridLayout);
-    if (qIsNaN(spacing) || d->columnSpacing == spacing)
+    if (qIsNaN(spacing) || columnSpacing() == spacing)
         return;
 
-    d->columnSpacing = spacing;
     d->engine.setSpacing(spacing, Qt::Horizontal);
     invalidate();
 }
@@ -568,21 +631,20 @@ void QQuickGridLayout::setColumnSpacing(qreal spacing)
     \qmlproperty real GridLayout::rowSpacing
 
     This property holds the spacing between each row.
-    The default value is \c 4.
+    The default value is \c 5.
 */
 qreal QQuickGridLayout::rowSpacing() const
 {
     Q_D(const QQuickGridLayout);
-    return d->rowSpacing;
+    return d->engine.spacing(Qt::Vertical, d->styleInfo);
 }
 
 void QQuickGridLayout::setRowSpacing(qreal spacing)
 {
     Q_D(QQuickGridLayout);
-    if (qIsNaN(spacing) || d->rowSpacing == spacing)
+    if (qIsNaN(spacing) || rowSpacing() == spacing)
         return;
 
-    d->rowSpacing = spacing;
     d->engine.setSpacing(spacing, Qt::Vertical);
     invalidate();
 }
@@ -798,9 +860,6 @@ QQuickLinearLayout::QQuickLinearLayout(Qt::Orientation orientation,
                                         QQuickItem *parent /*= 0*/)
     : QQuickGridLayoutBase(*new QQuickLinearLayoutPrivate, orientation, parent)
 {
-    Q_D(QQuickLinearLayout);
-    d->spacing = quickLayoutDefaultSpacing();
-    d->engine.setSpacing(d->spacing, Qt::Horizontal | Qt::Vertical);
 }
 
 /*!
@@ -843,29 +902,28 @@ QQuickLinearLayout::QQuickLinearLayout(Qt::Orientation orientation,
     \qmlproperty real RowLayout::spacing
 
     This property holds the spacing between each cell.
-    The default value is \c 4.
+    The default value is \c 5.
 */
 /*!
     \qmlproperty real ColumnLayout::spacing
 
     This property holds the spacing between each cell.
-    The default value is \c 4.
+    The default value is \c 5.
 */
 
 qreal QQuickLinearLayout::spacing() const
 {
     Q_D(const QQuickLinearLayout);
-    return d->spacing;
+    return d->engine.spacing(d->orientation, d->styleInfo);
 }
 
-void QQuickLinearLayout::setSpacing(qreal spacing)
+void QQuickLinearLayout::setSpacing(qreal space)
 {
     Q_D(QQuickLinearLayout);
-    if (qIsNaN(spacing) || d->spacing == spacing)
+    if (qIsNaN(space) || spacing() == space)
         return;
 
-    d->spacing = spacing;
-    d->engine.setSpacing(spacing, Qt::Horizontal | Qt::Vertical);
+    d->engine.setSpacing(space, Qt::Horizontal | Qt::Vertical);
     invalidate();
 }
 
